@@ -1,19 +1,19 @@
 /*
-	This is a classical Hello program
-	to test java2html.
+  This is a classical Hello program
+  to test source-highlight with Java programs.
+  
+  to have an html translation type
 
-	to have an html translation type
+	source-highlight -s java -f html --input Hello.java --output Hello.html
+	source-highlight -s java -f html < Hello.java > Hello.html
 
-		java2html --input Hello.java --output Hello.html
-		java2html < Hello.java > Hello.html
+  or type source-highlight --help for the list of options
 
-        or type java2html --help for options list
-
-	written by
-	Lorenzo Bettini <bettini@gnu.org>
-	http://w3.newnet.it/bettini
-	http://www.gnu.org/software/java2html
- */
+  written by
+  Lorenzo Bettini <bettini@gnu.org>
+  http://w3.newnet.it/bettini
+  http://www.gnu.org/software/src-highlite
+*/
 
 import java.io.* ;
 
